@@ -1,6 +1,8 @@
 
 from django import forms
 
+from django_select2.forms import Select2MultipleWidget
+
 from categories.models import Category
 
 
@@ -8,6 +10,7 @@ class StockReportForm(forms.Form):
 
     categories = forms.ModelMultipleChoiceField(
         required=False,
-        queryset=Category.objects.all())
+        queryset=Category.objects.all(),
+        widget=Select2MultipleWidget())
 
     ids = forms.CharField(required=False)
